# Documentation

The usage-oriented documentation (in Read the Docs style) is available [here](https://iai-group.github.io/DialogueKit/), with the corresponding sources contained in the source folder. Documentation related to development is found in the [Wiki](https://github.com/iai-group/dialoguekit/wiki).
